@@ -303,14 +303,14 @@ static void enable_uvm_persistence_mode(NvPdDevice *device) {
                     "Enabled UVM Persistence mode.");
             device->uvm_pm_mode = NV_UVM_PERSISTENCE_MODE_ENABLED;
             break;
-        } else if (status == NV_ERR_NVSWITCH_FABRIC_NOT_READY) {
+        } else if (status == NV_ERR_NVLINK_FABRIC_NOT_READY) {
             status = current_timestamp(&elapsedTime);
             if (status != NV_OK) {
                 break;
             }
 
             // restore the original error
-            status = NV_ERR_NVSWITCH_FABRIC_NOT_READY;
+            status = NV_ERR_NVLINK_FABRIC_NOT_READY;
 
             // giving up after timeout exceeded, otherwise retry
             if ((elapsedTime - startTime) >= fabricProbeTimeoutMs) {
@@ -325,7 +325,7 @@ static void enable_uvm_persistence_mode(NvPdDevice *device) {
     }
 
 out:
-    if (status == NV_ERR_NVSWITCH_FABRIC_NOT_READY) {
+    if (status == NV_ERR_NVLINK_FABRIC_NOT_READY) {
         syslog_device(&device->pci_info, LOG_WARNING,
                 "Could not Enable UVM Persistence mode because"
                 "the NVLink fabric is not ready: 0x%x", status);
@@ -366,7 +366,7 @@ static NvPdStatus set_device_mode(NvPdDevice *device, NvPersistenceMode mode)
             } else {
                 syslog_device(&device->pci_info, LOG_INFO,
                         "Disabled UVM Persistence mode.");
-                device->uvm_pm_mode = NV_PERSISTENCE_MODE_DISABLED;
+                device->uvm_pm_mode = NV_UVM_PERSISTENCE_MODE_DISABLED;
             }
         }
         /* If the new mode is disabled, we must close the device. */
